3.5.2. pypago.data.loaddata_sec_uv — PyPAGO 1.0.1 documentation

# 3.5.2. pypago.data.loaddata_sec_uv

`pypago.data.` `loaddata_sec_uv`(model_sections, filename_u, filename_v, dictvarname)

  Extracts the model output, interpolates if needed on west and north faces, and saves only the data along preselected sections and areas in structfile.

  Warning

  FOR NEMO MODEL ONLY

  Parameters: | file_location (str) – is where the model output can be found (full path), which name is `file_prefixSALT|TEMP|UVEL|VVEL.file_suffix.nc` loadarea (bool) – the loadarea option determines whether to load the temperature and salinity on the volumes computed using the `pypago.grid.areas_MODEL()` function

  Changed in version 20120515: JD PAGO WHOI